@@ -18,6 +18,7 @@ import os
 import sys
 import re
 from os import path
+import hashlib
 from calculate.lib.datavars import Variable, VariableError, ReadonlyVariable
 from calculate.lib.utils.portage import isPkgInstalled
 from calculate.lib.utils.files import readFile
@@ -253,6 +254,12 @@ class VariableOsInstallX11VideoDrv(VideoVariable):
         return ""
 
 
+class VariableOsInstallX11VideoDrvPrev(VariableOsInstallX11VideoDrv):
+    """
+    Предыдущее значение os_install_x11_videodrv
+    """
+
+
 class VariableHrVideoId(ReadonlyVariable):
     """
     BusID of video card
@@ -327,3 +334,60 @@ class VariableOsInstallFbResolution(ResolutionVariable):
         except (IOError, OSError):
             pass
         return "1024x768"
+
+class VariableClGrubImageHash(ReadonlyVariable):
+    """
+    Контрольная сумма изображения для grub
+    """
+    grub_image = "/boot/grub/grub-calculate.png"
+
+    def get_image_md5(self, source):
+        return hashlib.md5(readFile(source)).hexdigest()
+
+    def get(self):
+        if self.Get('cl_setup') == 'theme':
+            if path.exists(self.grub_image):
+                return self.get_image_md5(self.grub_image)
+        return ""
+
+class VariableClGrubImageUpdateSet(VariableClGrubImageHash):
+    """
+    Изображение для grub обновлилось
+    """
+
+    def get(self):
+        if self.Get('cl_setup') == 'themes':
+            if path.exists(self.grub_image):
+                newmd5 = self.get_image_md5(self.grub_image)
+            else:
+                newmd5 = ""
+            return "on" if newmd5 != self.Get('cl_grub_image_hash') else "off"
+        return "off"
+
+class VariableClSplashImageHash(ReadonlyVariable):
+    """
+    Контрольные суммы изображений для splashutils
+    """
+    hash_files = ("/etc/splash/calculate/images/verbose.md5",
+                  "/etc/splash/calculate/images/silent.md5")
+
+    def get_hash_data(self, sources):
+        data = []
+        for fn in sources:
+            data.append(readFile(fn) or "-")
+        return "".join(data)
+
+    def get(self):
+        if self.Get('cl_setup') == 'themes':
+            return self.get_hash_data(self.hash_files)
+        return ""
+
+class VariableClSplashImageUpdateSet(VariableClSplashImageHash):
+    """
+    Изображение для splash dracut обновлилось
+    """
+    def get(self):
+        if self.Get('cl_setup') == 'themes':
+            newmd5 = self.get_hash_data(self.hash_files)
+            return "on" if newmd5 != self.Get('cl_splash_image_hash') else "off"
+        return "off"
