@@ -30,7 +30,7 @@ from calculate.install.utils.cl_install import ClInstallAction
 from calculate.install.utils.cl_setup import (
     ClSetupLocaleAction, ClSetupVideoAction, ClSetupSystemAction,
     ClSetupBootAction, ClSetupNetworkAction, ClSetupAudioAction,
-    ClSetupSessionAction)
+    ClSetupSessionAction, ClSetupThemesAction)
 
 
 class Wsdl(WsdlBase):
@@ -368,6 +368,30 @@ class Wsdl(WsdlBase):
                 lambda group: group(_("Session"),
                                     normal=('cl_autologin',
                                             'cl_install_home_crypt_set'),
+                                    expert=(
+                                        'cl_templates_locate',
+                                        'cl_dispatch_conf',
+                                        'cl_verbose_set'),
+                                    next_label=_("Save"))]},
+        {
+            # настройка тем
+            'method_name': "setup_theme",
+            'category': None,
+            'title': __("Themes"),
+            'image': None,
+            'command': 'cl-setup-themes',
+            'gui': True,
+            'rights': ['setupthemes'],
+            'logic': {'Install': install.Install},
+            'action': ClSetupThemesAction,
+            'datavars': "install",
+            'native_error': (
+                VariableError, DataVarsError, install.InstallError),
+            'setvars': {'cl_action!': 'merge', 'cl_merge_pkg!': [None],
+                        'cl_merge_set!': "on", 'cl_setup': 'themes'},
+            'groups': [
+                lambda group: group(_("Session"),
+                                    normal=(),
                                     expert=(
                                         'cl_templates_locate',
                                         'cl_dispatch_conf',
